[![Documentation Status](https://readthedocs.org/projects/mugen/badge/?version=latest)](http://mugen.readthedocs.io/en/latest/?badge=latest)

# Mugen

Mugen is a Python library for gate-level SAT-based physical synthesis
of [Field-coupled Nanocomputing
(FCN)](https://www.springer.com/de/book/9783662437216) devices.

[Read the full documentation.](https://mugen.readthedocs.io/en/latest/?badge=latest)
